@@ -1,17 +1,19 @@
 mod client;
+mod inmemory_truststore;
 mod server;
 
 pub use client::*;
+pub use inmemory_truststore::*;
 pub use server::*;
 
 use serde::{Deserialize, Serialize};
-use themelio_stf::{ConsensusProof, Header, NetID, Transaction, TxHash};
+use themelio_stf::{BlockHeight, ConsensusProof, Header, NetID, Transaction, TxHash};
 use tmelcrypt::HashVal;
 
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct StateSummary {
     pub netid: NetID,
-    pub height: u64,
+    pub height: BlockHeight,
     pub header: Header,
     pub proof: ConsensusProof,
 }
@@ -28,9 +30,9 @@ pub enum Substate {
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub enum NodeRequest {
     SendTx(Transaction),
-    GetAbbrBlock(u64),
+    GetAbbrBlock(BlockHeight),
     GetSummary,
-    GetSmtBranch(u64, Substate, HashVal),
-    GetStakersRaw(u64),
-    GetPartialBlock(u64, Vec<TxHash>),
+    GetSmtBranch(BlockHeight, Substate, HashVal),
+    GetStakersRaw(BlockHeight),
+    GetPartialBlock(BlockHeight, Vec<TxHash>),
 }
